@@ -64,7 +64,7 @@ def test_afp_entities_linker(original_doc):
     )
     assert len(conso.annotations) < len(original_doc.annotations)
     conso_groups = group_annotations(conso, by_linking)
-    assert len(conso_groups["candidate"]) == 8
+    assert len(conso_groups["candidate"]) == 3
     assert len(conso_groups["person"]) == 2
     persons = [r.value.dict() for r in conso_groups["person"].ranges()]
     assert persons == IsList(
@@ -91,7 +91,7 @@ def test_afp_entities_linker(original_doc):
 
 def test_afp_entities_whitelist():
     testdir = Path(__file__).parent
-    source = Path(testdir, "data/afp_ner_fr-document-test-whitelist.json")
+    source = Path(testdir, "data/afp_ner_fr-document-test-whitelist2.json")
     with source.open("r") as fin:
         doc = json.load(fin)
         original_doc = Document(**doc)
@@ -109,20 +109,20 @@ def test_afp_entities_whitelist():
     )
     assert len(conso.annotations) < len(original_doc.annotations)
     conso_groups = group_annotations(conso, by_linking)
-    assert len(conso_groups["candidate"]) == 7
+    assert len(conso_groups["candidate"]) == 2
     assert len(conso_groups["person"]) == 2
     persons = [r.value.dict() for r in conso_groups["person"].ranges()]
     assert persons == IsList(
         IsPartialDict(
             label="AFPPerson",
-            text="reine Maxima",
+            text="Máxima des Pays-Bas",
             terms=IsList(
                 IsPartialDict(identifier=IsStr(regex=r"^afpperson.*")), length=1
             ),
         ),
         IsPartialDict(
             label="AFPPerson",
-            text="Letizia",
+            text="Lil Nas X",
             terms=IsList(
                 IsPartialDict(identifier=IsStr(regex=r"^afpperson.*")), length=1
             ),
